@@ -1,7 +1,7 @@
 package Pod::Weaver::Role::SectionText::HasCompletion;
 
 our $DATE = '2015-08-26'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use Moose::Role;
@@ -20,8 +20,8 @@ sub section_text_has_completion {
     $func_name = "_$func_name";
 
     my $text = <<_;
-The distribution comes with a shell completer script ($completer_name) for this
-script.
+The distribution comes with a shell completer script (L<$completer_name>) for
+this script.
 
 $h2 bash
 
@@ -76,7 +76,7 @@ Pod::Weaver::Role::SectionText::HasCompletion - Provide COMPLETION section text
 
 =head1 VERSION
 
-This document describes version 0.02 of Pod::Weaver::Role::SectionText::HasCompletion (from Perl distribution Pod-Weaver-Role-SectionText-HasCompletion), released on 2015-08-26.
+This document describes version 0.03 of Pod::Weaver::Role::SectionText::HasCompletion (from Perl distribution Pod-Weaver-Role-SectionText-HasCompletion), released on 2015-08-26.
 
 =head1 DESCRIPTION
 
